{% extends '_skeleton.jinja' %}

{% block predict %}
    float y_pred = 0;

    {% for k, tree in f.enumerate(trees) %}
        {% with i = 0 %}
            // tree #{{ k + 1 }}
            {% include 'randomforest/tree_regressor.jinja' %}
        {% endwith %}
    {% endfor %}

    return y_pred / {{ n_estimators }};
{% endblock %}